@@ -3,5 +3,5 @@ from django.conf.urls import patterns, url
 
 urlpatterns = patterns(
     'torrent_stream.views',
-    url(r'^js/(\w{32})/$', 'torrent_stream_js', name='torrent_stream_js'),
+    url(r'^assets/(\w{32}).js$', 'torrent_stream_js', name='torrent_stream_js'),
 )
