@@ -1,7 +1,7 @@
 import urllib
 
 from django.core.cache import cache
-from django.http import HttpResponse
+from django.http import HttpResponse, Http404
 
 from torrent_stream import settings
 from torrent_stream.helpers import get_content_id
@@ -11,6 +11,9 @@ from torrent_stream.exceptions import FailedResponse, ServerFault
 def torrent_stream_js(request, torrent_content_hash):
     cache_key = settings.TORRENT_STREAM_CACHE_PREFIX + torrent_content_hash
     torrent_stream = cache.get(cache_key)
+    if not torrent_stream:
+        raise Http404
+
     content_id = torrent_stream.get('content_id', None)
     if not content_id:
         torrent_content = torrent_stream.get('content', None)
